AliasOutput

Struct AliasOutput 

pub struct AliasOutput { /* private fields */ }
Available on crate feature block only.
Describes an alias account in the ledger that can be controlled by the state and governance controllers.

Implementations

Source

impl AliasOutput

pub fn try_from_dto( value: &AliasOutputDto, token_supply: u64, ) -> Result<Self, DtoError>

Available on crate feature dto only.
pub fn try_from_dto_unverified(value: &AliasOutputDto) -> Result<Self, DtoError>

Available on crate feature dto only.
pub fn try_from_dtos( amount: OutputBuilderAmountDto, native_tokens: Option<Vec<NativeTokenDto>>, alias_id: &AliasIdDto, state_index: Option<u32>, state_metadata: Option<Vec<u8>>, foundry_counter: Option<u32>, unlock_conditions: Vec<UnlockConditionDto>, features: Option<Vec<FeatureDto>>, immutable_features: Option<Vec<FeatureDto>>, token_supply: u64, ) -> Result<Self, DtoError>

Available on crate feature dto only.
Source

impl AliasOutput

pub const KIND: u8 = 4

The Output kind of an AliasOutput.

pub const STATE_METADATA_LENGTH_MAX: u16 = 8192

Maximum possible length in bytes of the state metadata.

pub const ALLOWED_UNLOCK_CONDITIONS: UnlockConditionFlags

The set of allowed UnlockConditions for an AliasOutput.

pub const ALLOWED_FEATURES: FeatureFlags

The set of allowed Features for an AliasOutput.

pub const ALLOWED_IMMUTABLE_FEATURES: FeatureFlags

The set of allowed immutable Features for an AliasOutput.

pub fn new_with_amount( amount: u64, alias_id: AliasId, token_supply: u64, ) -> Result<Self, Error>

Creates a new AliasOutput with a provided amount.

pub fn new_with_minimum_storage_deposit( alias_id: AliasId, rent_structure: RentStructure, token_supply: u64, ) -> Result<Self, Error>

Creates a new AliasOutput with a provided rent structure. The amount will be set to the minimum storage deposit.

pub fn build_with_amount( amount: u64, alias_id: AliasId, ) -> Result<AliasOutputBuilder, Error>

Creates a new AliasOutputBuilder with a provided amount.

pub fn build_with_minimum_storage_deposit( rent_structure: RentStructure, alias_id: AliasId, ) -> Result<AliasOutputBuilder, Error>

Creates a new AliasOutputBuilder with a provided rent structure. The amount will be set to the minimum storage deposit.

pub fn amount(&self) -> u64

pub fn native_tokens(&self) -> &NativeTokens

pub fn alias_id(&self) -> &AliasId

pub fn alias_id_non_null(&self, output_id: &OutputId) -> AliasId

Returns the alias ID if not null, or creates it from the output ID.

pub fn state_index(&self) -> u32

pub fn state_metadata(&self) -> &[u8]

pub fn foundry_counter(&self) -> u32

pub fn unlock_conditions(&self) -> &UnlockConditions

pub fn features(&self) -> &Features

pub fn immutable_features(&self) -> &Features

pub fn state_controller_address(&self) -> &Address

pub fn governor_address(&self) -> &Address

pub fn chain_id(&self) -> ChainId

pub fn alias_address(&self, output_id: &OutputId) -> AliasAddress

Returns the alias address for this output.

pub fn unlock( &self, output_id: &OutputId, unlock: &Unlock, inputs: &[(OutputId, &Output)], context: &mut ValidationContext<'_>, ) -> Result<(), ConflictReason>