pub struct BasicOutput { /* private fields */ }block only.Expand description
Describes a basic output with optional features.
Implementations
Sourceimpl BasicOutput
impl BasicOutput
pub fn try_from_dto( value: &BasicOutputDto, token_supply: u64, ) -> Result<Self, DtoError>
dto only.pub fn try_from_dto_unverified(value: &BasicOutputDto) -> Result<Self, DtoError>
dto only.pub fn try_from_dtos( amount: OutputBuilderAmountDto, native_tokens: Option<Vec<NativeTokenDto>>, unlock_conditions: Vec<UnlockConditionDto>, features: Option<Vec<FeatureDto>>, token_supply: u64, ) -> Result<Self, DtoError>
dto only.Sourceimpl BasicOutput
impl BasicOutput
Sourcepub const KIND: u8 = 3
pub const KIND: u8 = 3
The Output kind of an BasicOutput.
Sourcepub const ALLOWED_FEATURES: FeatureFlags
pub const ALLOWED_FEATURES: FeatureFlags
The set of allowed Features for an BasicOutput.
Sourcepub fn new_with_amount(amount: u64, token_supply: u64) -> Result<Self, Error>
pub fn new_with_amount(amount: u64, token_supply: u64) -> Result<Self, Error>
Creates a new BasicOutput with a provided amount.
Sourcepub fn new_with_minimum_storage_deposit(
rent_structure: RentStructure,
token_supply: u64,
) -> Result<Self, Error>
pub fn new_with_minimum_storage_deposit( rent_structure: RentStructure, token_supply: u64, ) -> Result<Self, Error>
Creates a new BasicOutput with a provided rent structure.
The amount will be set to the minimum storage deposit.
Sourcepub fn build_with_amount(amount: u64) -> Result<BasicOutputBuilder, Error>
pub fn build_with_amount(amount: u64) -> Result<BasicOutputBuilder, Error>
Creates a new BasicOutputBuilder with a provided amount.
Sourcepub fn build_with_minimum_storage_deposit(
rent_structure: RentStructure,
) -> Result<BasicOutputBuilder, Error>
pub fn build_with_minimum_storage_deposit( rent_structure: RentStructure, ) -> Result<BasicOutputBuilder, Error>
Creates a new BasicOutputBuilder with a provided rent structure.
The amount will be set to the minimum storage deposit.
Sourcepub fn native_tokens(&self) -> &NativeTokens
pub fn native_tokens(&self) -> &NativeTokens
Sourcepub fn unlock_conditions(&self) -> &UnlockConditions
pub fn unlock_conditions(&self) -> &UnlockConditions
Sourcepub fn unlock(
&self,
_output_id: &OutputId,
unlock: &Unlock,
inputs: &[(OutputId, &Output)],
context: &mut ValidationContext<'_>,
) -> Result<(), ConflictReason>
pub fn unlock( &self, _output_id: &OutputId, unlock: &Unlock, inputs: &[(OutputId, &Output)], context: &mut ValidationContext<'_>, ) -> Result<(), ConflictReason>
Sourcepub fn simple_deposit_address(&self) -> Option<&Address>
pub fn simple_deposit_address(&self) -> Option<&Address>
Returns the address of the unlock conditions if the output is a simple deposit. Simple deposit outputs are basic outputs with only an address unlock condition, no native tokens and no features. They are used to return storage deposits.