pub enum Output {
Treasury(TreasuryOutput),
Basic(BasicOutput),
Alias(AliasOutput),
Foundry(FoundryOutput),
Nft(NftOutput),
}block only.Expand description
A generic output that can represent different types defining the deposit of funds.
Variants
Treasury(TreasuryOutput)
A treasury output.
Basic(BasicOutput)
A basic output.
Alias(AliasOutput)
An alias output.
Foundry(FoundryOutput)
A foundry output.
Nft(NftOutput)
An NFT output.
Implementations
Sourceimpl Output
impl Output
Sourcepub const AMOUNT_MIN: u64 = 1
pub const AMOUNT_MIN: u64 = 1
Minimum amount for an output.
Sourcepub fn native_tokens(&self) -> Option<&NativeTokens>
pub fn native_tokens(&self) -> Option<&NativeTokens>
Returns the native tokens of an Output, if any.
Sourcepub fn unlock_conditions(&self) -> Option<&UnlockConditions>
pub fn unlock_conditions(&self) -> Option<&UnlockConditions>
Returns the unlock conditions of an Output, if any.
Sourcepub fn immutable_features(&self) -> Option<&Features>
pub fn immutable_features(&self) -> Option<&Features>
Returns the immutable features of an Output, if any.
Sourcepub fn is_treasury(&self) -> bool
pub fn is_treasury(&self) -> bool
Checks whether the output is a TreasuryOutput.
Sourcepub fn as_treasury(&self) -> &TreasuryOutput
pub fn as_treasury(&self) -> &TreasuryOutput
Gets the output as an actual TreasuryOutput.
PANIC: do not call on a non-treasury output.
Sourcepub fn is_basic(&self) -> bool
pub fn is_basic(&self) -> bool
Checks whether the output is a BasicOutput.
Sourcepub fn as_basic(&self) -> &BasicOutput
pub fn as_basic(&self) -> &BasicOutput
Gets the output as an actual BasicOutput.
PANIC: do not call on a non-basic output.
Sourcepub fn is_alias(&self) -> bool
pub fn is_alias(&self) -> bool
Checks whether the output is an AliasOutput.
Sourcepub fn as_alias(&self) -> &AliasOutput
pub fn as_alias(&self) -> &AliasOutput
Gets the output as an actual AliasOutput.
PANIC: do not call on a non-alias output.
Sourcepub fn is_foundry(&self) -> bool
pub fn is_foundry(&self) -> bool
Checks whether the output is a FoundryOutput.
Sourcepub fn as_foundry(&self) -> &FoundryOutput
pub fn as_foundry(&self) -> &FoundryOutput
Gets the output as an actual FoundryOutput.
PANIC: do not call on a non-foundry output.
Sourcepub fn as_nft(&self) -> &NftOutput
pub fn as_nft(&self) -> &NftOutput
Gets the output as an actual NftOutput.
PANIC: do not call on a non-nft output.
Sourcepub fn required_and_unlocked_address(
&self,
current_time: u32,
output_id: &OutputId,
alias_transition: Option<AliasTransition>,
) -> Result<(Address, Option<Address>), Error>
pub fn required_and_unlocked_address( &self, current_time: u32, output_id: &OutputId, alias_transition: Option<AliasTransition>, ) -> Result<(Address, Option<Address>), Error>
Returns the address that is required to unlock this Output and the alias or nft address that gets
unlocked by it, if it’s an alias or nft.
If no alias_transition has been provided, assumes a state transition.
Sourcepub fn verify_state_transition(
current_state: Option<&Self>,
next_state: Option<&Self>,
context: &ValidationContext<'_>,
) -> Result<(), StateTransitionError>
pub fn verify_state_transition( current_state: Option<&Self>, next_state: Option<&Self>, context: &ValidationContext<'_>, ) -> Result<(), StateTransitionError>
Sourcepub fn verify_storage_deposit(
&self,
rent_structure: RentStructure,
token_supply: u64,
) -> Result<(), Error>
pub fn verify_storage_deposit( &self, rent_structure: RentStructure, token_supply: u64, ) -> Result<(), Error>
Verifies if a valid storage deposit was made. Each Output has to have an amount that covers its associated
byte cost, given by RentStructure.
If there is a StorageDepositReturnUnlockCondition,
its amount is also checked.