pub struct TreasuryOutput { /* private fields */ }Available on crate feature
block only.Expand description
TreasuryOutput is an output which holds the treasury of a network.
Implementations
Sourceimpl TreasuryOutput
impl TreasuryOutput
pub fn try_from_dto( value: &TreasuryOutputDto, token_supply: u64, ) -> Result<Self, DtoError>
Available on crate feature
dto only.pub fn try_from_dto_unverified( value: &TreasuryOutputDto, ) -> Result<Self, DtoError>
Available on crate feature
dto only.Trait Implementations
Sourceimpl Clone for TreasuryOutput
impl Clone for TreasuryOutput
Sourcefn clone(&self) -> TreasuryOutput
fn clone(&self) -> TreasuryOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TreasuryOutput
impl Debug for TreasuryOutput
Sourceimpl<'de> Deserialize<'de> for TreasuryOutput
impl<'de> Deserialize<'de> for TreasuryOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&TreasuryOutput> for TreasuryOutputDto
Available on crate feature dto only.
impl From<&TreasuryOutput> for TreasuryOutputDto
Available on crate feature
dto only.Sourcefn from(value: &TreasuryOutput) -> Self
fn from(value: &TreasuryOutput) -> Self
Converts to this type from the input type.
Sourceimpl From<TreasuryOutput> for Output
impl From<TreasuryOutput> for Output
Sourcefn from(original: TreasuryOutput) -> Output
fn from(original: TreasuryOutput) -> Output
Converts to this type from the input type.
Sourceimpl Hash for TreasuryOutput
impl Hash for TreasuryOutput
Sourceimpl Ord for TreasuryOutput
impl Ord for TreasuryOutput
Sourcefn cmp(&self, other: &TreasuryOutput) -> Ordering
fn cmp(&self, other: &TreasuryOutput) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl Packable for TreasuryOutput
impl Packable for TreasuryOutput
Sourcetype UnpackError = Error
type UnpackError = Error
The error type that can be returned if some semantic error occurs while unpacking. Read more
Sourcetype UnpackVisitor = ProtocolParameters
type UnpackVisitor = ProtocolParameters
FIXME: docs
Sourcefn pack<P: Packer>(&self, packer: &mut P) -> Result<(), P::Error>
fn pack<P: Packer>(&self, packer: &mut P) -> Result<(), P::Error>
Packs this value into the given
Packer.Sourcefn unpack<U: Unpacker, const VERIFY: bool>(
unpacker: &mut U,
visitor: &Self::UnpackVisitor,
) -> Result<Self, UnpackError<Self::UnpackError, U::Error>>
fn unpack<U: Unpacker, const VERIFY: bool>( unpacker: &mut U, visitor: &Self::UnpackVisitor, ) -> Result<Self, UnpackError<Self::UnpackError, U::Error>>
Unpacks this value from the given
Unpacker. The VERIFY generic parameter can be used to skip additional
syntactic checks.Sourceimpl PartialEq for TreasuryOutput
impl PartialEq for TreasuryOutput
Sourcefn eq(&self, other: &TreasuryOutput) -> bool
fn eq(&self, other: &TreasuryOutput) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TreasuryOutput
impl PartialOrd for TreasuryOutput
Sourceimpl Serialize for TreasuryOutput
impl Serialize for TreasuryOutput
impl Eq for TreasuryOutput
impl StructuralPartialEq for TreasuryOutput