Crate iota_types

Crate iota_types 

Common types required by nodes and clients APIs like blocks, responses and DTOs.

Modules

apiapi
API-related types like responses and DTOs.
blockblock
Core data types for blocks in the tangle.

Macros

create_bitflagsblock
A convenience macro to work around the fact the [bitflags] crate does not yet support iterating over the individual flags. This macro essentially creates the [bitflags] and puts the individual flags into an associated constant pub const ALL_FLAGS: &'static [].
impl_idblock
TODO
string_serde_implblock and serde
Helper macro to serialize types to string via serde.