pub struct AliasOutput { /* private fields */ }block only.Expand description
Describes an alias account in the ledger that can be controlled by the state and governance controllers.
Implementations
Sourceimpl AliasOutput
impl AliasOutput
pub fn try_from_dto( value: &AliasOutputDto, token_supply: u64, ) -> Result<Self, DtoError>
dto only.pub fn try_from_dto_unverified(value: &AliasOutputDto) -> Result<Self, DtoError>
dto only.pub fn try_from_dtos( amount: OutputBuilderAmountDto, native_tokens: Option<Vec<NativeTokenDto>>, alias_id: &AliasIdDto, state_index: Option<u32>, state_metadata: Option<Vec<u8>>, foundry_counter: Option<u32>, unlock_conditions: Vec<UnlockConditionDto>, features: Option<Vec<FeatureDto>>, immutable_features: Option<Vec<FeatureDto>>, token_supply: u64, ) -> Result<Self, DtoError>
dto only.Sourceimpl AliasOutput
impl AliasOutput
Sourcepub const KIND: u8 = 4
pub const KIND: u8 = 4
The Output kind of an AliasOutput.
Sourcepub const STATE_METADATA_LENGTH_MAX: u16 = 8192
pub const STATE_METADATA_LENGTH_MAX: u16 = 8192
Maximum possible length in bytes of the state metadata.
Sourcepub const ALLOWED_UNLOCK_CONDITIONS: UnlockConditionFlags
pub const ALLOWED_UNLOCK_CONDITIONS: UnlockConditionFlags
The set of allowed UnlockConditions for an AliasOutput.
Sourcepub const ALLOWED_FEATURES: FeatureFlags
pub const ALLOWED_FEATURES: FeatureFlags
The set of allowed Features for an AliasOutput.
Sourcepub const ALLOWED_IMMUTABLE_FEATURES: FeatureFlags
pub const ALLOWED_IMMUTABLE_FEATURES: FeatureFlags
The set of allowed immutable Features for an AliasOutput.
Sourcepub fn new_with_amount(
amount: u64,
alias_id: AliasId,
token_supply: u64,
) -> Result<Self, Error>
pub fn new_with_amount( amount: u64, alias_id: AliasId, token_supply: u64, ) -> Result<Self, Error>
Creates a new AliasOutput with a provided amount.
Sourcepub fn new_with_minimum_storage_deposit(
alias_id: AliasId,
rent_structure: RentStructure,
token_supply: u64,
) -> Result<Self, Error>
pub fn new_with_minimum_storage_deposit( alias_id: AliasId, rent_structure: RentStructure, token_supply: u64, ) -> Result<Self, Error>
Creates a new AliasOutput with a provided rent structure.
The amount will be set to the minimum storage deposit.
Sourcepub fn build_with_amount(
amount: u64,
alias_id: AliasId,
) -> Result<AliasOutputBuilder, Error>
pub fn build_with_amount( amount: u64, alias_id: AliasId, ) -> Result<AliasOutputBuilder, Error>
Creates a new AliasOutputBuilder with a provided amount.
Sourcepub fn build_with_minimum_storage_deposit(
rent_structure: RentStructure,
alias_id: AliasId,
) -> Result<AliasOutputBuilder, Error>
pub fn build_with_minimum_storage_deposit( rent_structure: RentStructure, alias_id: AliasId, ) -> Result<AliasOutputBuilder, Error>
Creates a new AliasOutputBuilder with a provided rent structure.
The amount will be set to the minimum storage deposit.
Sourcepub fn native_tokens(&self) -> &NativeTokens
pub fn native_tokens(&self) -> &NativeTokens
Sourcepub fn alias_id_non_null(&self, output_id: &OutputId) -> AliasId
pub fn alias_id_non_null(&self, output_id: &OutputId) -> AliasId
Returns the alias ID if not null, or creates it from the output ID.
Sourcepub fn state_index(&self) -> u32
pub fn state_index(&self) -> u32
Sourcepub fn state_metadata(&self) -> &[u8] ⓘ
pub fn state_metadata(&self) -> &[u8] ⓘ
Sourcepub fn foundry_counter(&self) -> u32
pub fn foundry_counter(&self) -> u32
Sourcepub fn unlock_conditions(&self) -> &UnlockConditions
pub fn unlock_conditions(&self) -> &UnlockConditions
Sourcepub fn immutable_features(&self) -> &Features
pub fn immutable_features(&self) -> &Features
Sourcepub fn state_controller_address(&self) -> &Address
pub fn state_controller_address(&self) -> &Address
Sourcepub fn governor_address(&self) -> &Address
pub fn governor_address(&self) -> &Address
Sourcepub fn alias_address(&self, output_id: &OutputId) -> AliasAddress
pub fn alias_address(&self, output_id: &OutputId) -> AliasAddress
Returns the alias address for this output.
Sourcepub fn unlock(
&self,
output_id: &OutputId,
unlock: &Unlock,
inputs: &[(OutputId, &Output)],
context: &mut ValidationContext<'_>,
) -> Result<(), ConflictReason>
pub fn unlock( &self, output_id: &OutputId, unlock: &Unlock, inputs: &[(OutputId, &Output)], context: &mut ValidationContext<'_>, ) -> Result<(), ConflictReason>